aboutsummaryrefslogtreecommitdiffstats
diff options
context:
space:
mode:
-rw-r--r--gtk/Makefile.am2
-rw-r--r--gtk/Makefile.common18
-rw-r--r--gtk/conversations_eth.c (renamed from gtk/endpoint_talkers_eth.c)11
-rw-r--r--gtk/conversations_fc.c (renamed from gtk/endpoint_talkers_fc.c)11
-rw-r--r--gtk/conversations_fddi.c (renamed from gtk/endpoint_talkers_fddi.c)11
-rw-r--r--gtk/conversations_ip.c (renamed from gtk/endpoint_talkers_ip.c)11
-rw-r--r--gtk/conversations_ipx.c (renamed from gtk/endpoint_talkers_ipx.c)11
-rw-r--r--gtk/conversations_table.c (renamed from gtk/endpoint_talkers_table.c)134
-rw-r--r--gtk/conversations_table.h (renamed from gtk/endpoint_talkers_table.h)22
-rw-r--r--gtk/conversations_tcpip.c (renamed from gtk/endpoint_talkers_tcpip.c)11
-rw-r--r--gtk/conversations_tr.c (renamed from gtk/endpoint_talkers_tr.c)11
-rw-r--r--gtk/conversations_udpip.c (renamed from gtk/endpoint_talkers_udpip.c)11
-rw-r--r--gtk/menu.c2
13 files changed, 129 insertions, 137 deletions
diff --git a/gtk/Makefile.am b/gtk/Makefile.am
index a591fb4f5a..03d3d05dba 100644
--- a/gtk/Makefile.am
+++ b/gtk/Makefile.am
@@ -44,10 +44,10 @@ noinst_HEADERS = \
colors.h \
column_prefs.h \
compat_macros.h \
+ conversations_table.h \
decode_as_dlg.h \
dfilter_expr_dlg.h \
dlg_utils.h \
- endpoint_talkers_table.h \
file_dlg.h \
filter_dlg.h \
find_dlg.h \
diff --git a/gtk/Makefile.common b/gtk/Makefile.common
index 9959f3d358..1cd2e5697e 100644
--- a/gtk/Makefile.common
+++ b/gtk/Makefile.common
@@ -40,10 +40,10 @@ ETHEREAL_GTK_SRC = \
color_utils.c \
colors.c \
column_prefs.c \
+ conversations_table.c \
decode_as_dlg.c \
dfilter_expr_dlg.c \
dlg_utils.c \
- endpoint_talkers_table.c \
ethereal-tap-register.c \
file_dlg.c \
filter_dlg.c \
@@ -88,15 +88,15 @@ ETHEREAL_TAP_SRC = \
ansi_a_stat.c \
ansi_map_stat.c \
bootp_stat.c \
+ conversations_eth.c \
+ conversations_fc.c \
+ conversations_fddi.c \
+ conversations_ip.c \
+ conversations_ipx.c \
+ conversations_tcpip.c \
+ conversations_tr.c \
+ conversations_udpip.c \
dcerpc_stat.c \
- endpoint_talkers_eth.c \
- endpoint_talkers_fc.c \
- endpoint_talkers_fddi.c \
- endpoint_talkers_ip.c \
- endpoint_talkers_ipx.c \
- endpoint_talkers_tcpip.c \
- endpoint_talkers_tr.c \
- endpoint_talkers_udpip.c \
fc_stat.c \
gsm_a_stat.c \
gsm_map_stat.c \
diff --git a/gtk/endpoint_talkers_eth.c b/gtk/conversations_eth.c
index e60a9e300f..bdad3af9b6 100644
--- a/gtk/endpoint_talkers_eth.c
+++ b/gtk/conversations_eth.c
@@ -1,5 +1,5 @@
-/* endpoint_talkers_eth.c
- * endpoint_talkers_eth 2003 Ronnie Sahlberg
+/* conversations_eth.c
+ * conversations_eth 2003 Ronnie Sahlberg
*
* $Id$
*
@@ -36,17 +36,16 @@
#include "tap_menu.h"
#include "../tap.h"
#include "../register.h"
-#include "endpoint_talkers_table.h"
+#include "conversations_table.h"
#include <epan/dissectors/packet-eth.h>
static int
-eth_talkers_packet(void *pit, packet_info *pinfo, epan_dissect_t *edt _U_, void *vip)
+eth_talkers_packet(void *pct, packet_info *pinfo, epan_dissect_t *edt _U_, void *vip)
{
- endpoints_table *talkers=(endpoints_table *)pit;
eth_hdr *ehdr=vip;
- add_ett_table_data(talkers, &ehdr->src, &ehdr->dst, 0, 0, 1, pinfo->fd->pkt_len, SAT_ETHER, PT_NONE);
+ add_ett_table_data((conversations_table *)pct, &ehdr->src, &ehdr->dst, 0, 0, 1, pinfo->fd->pkt_len, SAT_ETHER, PT_NONE);
return 1;
}
diff --git a/gtk/endpoint_talkers_fc.c b/gtk/conversations_fc.c
index dbe9ec3054..83802d7a56 100644
--- a/gtk/endpoint_talkers_fc.c
+++ b/gtk/conversations_fc.c
@@ -1,5 +1,5 @@
-/* endpoint_talkers_fc.c
- * endpoint_talkers_fc 2003 Ronnie Sahlberg
+/* conversations_fc.c
+ * conversations_fc 2003 Ronnie Sahlberg
*
* $Id$
*
@@ -36,17 +36,16 @@
#include "tap_menu.h"
#include "../tap.h"
#include "../register.h"
-#include "endpoint_talkers_table.h"
+#include "conversations_table.h"
#include <epan/dissectors/packet-fc.h>
static int
-fc_talkers_packet(void *pit, packet_info *pinfo, epan_dissect_t *edt _U_, void *vip)
+fc_talkers_packet(void *pct, packet_info *pinfo, epan_dissect_t *edt _U_, void *vip)
{
- endpoints_table *talkers=(endpoints_table *)pit;
fc_hdr *fchdr=vip;
- add_ett_table_data(talkers, &fchdr->s_id, &fchdr->d_id, 0, 0, 1, pinfo->fd->pkt_len, SAT_NONE, PT_NONE);
+ add_ett_table_data((conversations_table *)pct, &fchdr->s_id, &fchdr->d_id, 0, 0, 1, pinfo->fd->pkt_len, SAT_NONE, PT_NONE);
return 1;
}
diff --git a/gtk/endpoint_talkers_fddi.c b/gtk/conversations_fddi.c
index 0f1c9d5870..ddf09f9817 100644
--- a/gtk/endpoint_talkers_fddi.c
+++ b/gtk/conversations_fddi.c
@@ -1,5 +1,5 @@
-/* endpoint_talkers_fddi.c
- * endpoint_talkers_fddi 2003 Ronnie Sahlberg
+/* conversations_fddi.c
+ * conversations_fddi 2003 Ronnie Sahlberg
*
* $Id$
*
@@ -36,17 +36,16 @@
#include "tap_menu.h"
#include "../tap.h"
#include "../register.h"
-#include "endpoint_talkers_table.h"
+#include "conversations_table.h"
#include <epan/dissectors/packet-fddi.h>
static int
-fddi_talkers_packet(void *pit, packet_info *pinfo, epan_dissect_t *edt _U_, void *vip)
+fddi_talkers_packet(void *pct, packet_info *pinfo, epan_dissect_t *edt _U_, void *vip)
{
- endpoints_table *talkers=(endpoints_table *)pit;
fddi_hdr *ehdr=vip;
- add_ett_table_data(talkers, &ehdr->src, &ehdr->dst, 0, 0, 1, pinfo->fd->pkt_len, SAT_FDDI, PT_NONE);
+ add_ett_table_data((conversations_table *)pct, &ehdr->src, &ehdr->dst, 0, 0, 1, pinfo->fd->pkt_len, SAT_FDDI, PT_NONE);
return 1;
}
diff --git a/gtk/endpoint_talkers_ip.c b/gtk/conversations_ip.c
index 0b165d912d..b72a231d23 100644
--- a/gtk/endpoint_talkers_ip.c
+++ b/gtk/conversations_ip.c
@@ -1,5 +1,5 @@
-/* endpoint_talkers_ip.c
- * endpoint_talkers_ip 2003 Ronnie Sahlberg
+/* conversations_ip.c
+ * conversations_ip 2003 Ronnie Sahlberg
*
* $Id$
*
@@ -36,17 +36,16 @@
#include "tap_menu.h"
#include "../tap.h"
#include "../register.h"
-#include "endpoint_talkers_table.h"
+#include "conversations_table.h"
#include <epan/dissectors/packet-ip.h>
static int
-ip_talkers_packet(void *pit, packet_info *pinfo, epan_dissect_t *edt _U_, void *vip)
+ip_talkers_packet(void *pct, packet_info *pinfo, epan_dissect_t *edt _U_, void *vip)
{
- endpoints_table *talkers=(endpoints_table *)pit;
e_ip *iph=vip;
- add_ett_table_data(talkers, &iph->ip_src, &iph->ip_dst, 0, 0, 1, pinfo->fd->pkt_len, SAT_NONE, PT_NONE);
+ add_ett_table_data((conversations_table *)pct, &iph->ip_src, &iph->ip_dst, 0, 0, 1, pinfo->fd->pkt_len, SAT_NONE, PT_NONE);
return 1;
}
diff --git a/gtk/endpoint_talkers_ipx.c b/gtk/conversations_ipx.c
index 4fc501c5f3..b4761359fb 100644
--- a/gtk/endpoint_talkers_ipx.c
+++ b/gtk/conversations_ipx.c
@@ -1,5 +1,5 @@
-/* endpoint_talkers_ipx.c
- * endpoint_talkers_ipx 2003 Ronnie Sahlberg
+/* conversations_ipx.c
+ * conversations_ipx 2003 Ronnie Sahlberg
*
* $Id$
*
@@ -36,17 +36,16 @@
#include "tap_menu.h"
#include "../tap.h"
#include "../register.h"
-#include "endpoint_talkers_table.h"
+#include "conversations_table.h"
#include <epan/dissectors/packet-ipx.h>
static int
-ipx_talkers_packet(void *pit, packet_info *pinfo, epan_dissect_t *edt _U_, void *vip)
+ipx_talkers_packet(void *pct, packet_info *pinfo, epan_dissect_t *edt _U_, void *vip)
{
- endpoints_table *talkers=(endpoints_table *)pit;
ipxhdr_t *ipxh=vip;
- add_ett_table_data(talkers, &ipxh->ipx_src, &ipxh->ipx_dst, 0, 0, 1, pinfo->fd->pkt_len, SAT_NONE, PT_NONE);
+ add_ett_table_data((conversations_table *)pct, &ipxh->ipx_src, &ipxh->ipx_dst, 0, 0, 1, pinfo->fd->pkt_len, SAT_NONE, PT_NONE);
return 1;
}
diff --git a/gtk/endpoint_talkers_tcpip.c b/gtk/conversations_tcpip.c
index 04151317f2..603e266b41 100644
--- a/gtk/endpoint_talkers_tcpip.c
+++ b/gtk/conversations_tcpip.c
@@ -1,5 +1,5 @@
-/* endpoint_talkers_tcpip.c
- * endpoint_talkers_tcpip 2003 Ronnie Sahlberg
+/* conversations_tcpip.c
+ * conversations_tcpip 2003 Ronnie Sahlberg
*
* $Id$
*
@@ -36,17 +36,16 @@
#include "tap_menu.h"
#include "../tap.h"
#include "../register.h"
-#include "endpoint_talkers_table.h"
+#include "conversations_table.h"
#include <epan/dissectors/packet-tcp.h>
static int
-tcpip_talkers_packet(void *pit, packet_info *pinfo, epan_dissect_t *edt _U_, void *vip)
+tcpip_talkers_packet(void *pct, packet_info *pinfo, epan_dissect_t *edt _U_, void *vip)
{
- endpoints_table *talkers=(endpoints_table *)pit;
struct tcpheader *tcphdr=vip;
- add_ett_table_data(talkers, &tcphdr->ip_src, &tcphdr->ip_dst, tcphdr->th_sport, tcphdr->th_dport, 1, pinfo->fd->pkt_len, SAT_NONE, PT_TCP);
+ add_ett_table_data((conversations_table *)pct, &tcphdr->ip_src, &tcphdr->ip_dst, tcphdr->th_sport, tcphdr->th_dport, 1, pinfo->fd->pkt_len, SAT_NONE, PT_TCP);
return 1;
}
diff --git a/gtk/endpoint_talkers_tr.c b/gtk/conversations_tr.c
index a859c4e4df..ec174b284a 100644
--- a/gtk/endpoint_talkers_tr.c
+++ b/gtk/conversations_tr.c
@@ -1,5 +1,5 @@
-/* endpoint_talkers_tr.c
- * endpoint_talkers_tr 2003 Ronnie Sahlberg
+/* conversations_tr.c
+ * conversations_tr 2003 Ronnie Sahlberg
*
* $Id$
*
@@ -36,17 +36,16 @@
#include "tap_menu.h"
#include "../tap.h"
#include "../register.h"
-#include "endpoint_talkers_table.h"
+#include "conversations_table.h"
#include <epan/dissectors/packet-tr.h>
static int
-tr_talkers_packet(void *pit, packet_info *pinfo, epan_dissect_t *edt _U_, void *vip)
+tr_talkers_packet(void *pct, packet_info *pinfo, epan_dissect_t *edt _U_, void *vip)
{
- endpoints_table *talkers=(endpoints_table *)pit;
tr_hdr *trhdr=vip;
- add_ett_table_data(talkers, &trhdr->src, &trhdr->dst, 0, 0, 1, pinfo->fd->pkt_len, SAT_TOKENRING, PT_NONE);
+ add_ett_table_data((conversations_table *)pct, &trhdr->src, &trhdr->dst, 0, 0, 1, pinfo->fd->pkt_len, SAT_TOKENRING, PT_NONE);
return 1;
}
diff --git a/gtk/endpoint_talkers_udpip.c b/gtk/conversations_udpip.c
index 838c6856e8..b22559469e 100644
--- a/gtk/endpoint_talkers_udpip.c
+++ b/gtk/conversations_udpip.c
@@ -1,5 +1,5 @@
-/* endpoint_talkers_udpip.c
- * endpoint_talkers_udpip 2003 Ronnie Sahlberg
+/* conversations_udpip.c
+ * conversations_udpip 2003 Ronnie Sahlberg
*
* $Id$
*
@@ -36,17 +36,16 @@
#include "tap_menu.h"
#include "../tap.h"
#include "../register.h"
-#include "endpoint_talkers_table.h"
+#include "conversations_table.h"
#include <epan/dissectors/packet-udp.h>
static int
-udpip_talkers_packet(void *pit, packet_info *pinfo, epan_dissect_t *edt _U_, void *vip)
+udpip_talkers_packet(void *pct, packet_info *pinfo, epan_dissect_t *edt _U_, void *vip)
{
- endpoints_table *talkers=(endpoints_table *)pit;
e_udphdr *udphdr=vip;
- add_ett_table_data(talkers, &udphdr->ip_src, &udphdr->ip_dst, udphdr->uh_sport, udphdr->uh_dport, 1, pinfo->fd->pkt_len, SAT_NONE, PT_UDP);
+ add_ett_table_data((conversations_table *)pct, &udphdr->ip_src, &udphdr->ip_dst, udphdr->uh_sport, udphdr->uh_dport, 1, pinfo->fd->pkt_len, SAT_NONE, PT_UDP);
return 1;
}
diff --git a/gtk/menu.c b/gtk/menu.c
index bf911a8f19..bd12b583f7 100644
--- a/gtk/menu.c
+++ b/gtk/menu.c
@@ -69,7 +69,7 @@
#include "recent.h"
#include "../ui_util.h"
#include "proto_draw.h"
-#include "endpoint_talkers_table.h"
+#include "conversations_table.h"
#include "hostlist_table.h"
#include "simple_dialog.h"
#include <epan/timestamp.h>
diff --git a/gtk/endpoint_talkers_table.c b/gtk/conversations_table.c
index b74dce51ba..19f3c7cb11 100644
--- a/gtk/endpoint_talkers_table.c
+++ b/gtk/conversations_table.c
@@ -1,8 +1,8 @@
/* mem leak should free the column_arrows when the table is destroyed */
/* endpoint_talkers_table.c
* endpoint_talkers_table 2003 Ronnie Sahlberg
* Helper routines common to all endpoint talkers tap.
*
* $Id$
*
@@ -41,7 +41,7 @@
#include "epan/to_str.h"
#include "epan/resolv.h"
#include "sat.h"
-#include "endpoint_talkers_table.h"
+#include "conversations_table.h"
#include "image/clist_ascend.xpm"
#include "image/clist_descend.xpm"
#include "simple_dialog.h"
@@ -208,7 +208,7 @@ typedef struct column_arrows {
static void
-reset_ett_table_data(endpoints_table *et)
+reset_ett_table_data(conversations_table *et)
{
guint32 i;
char title[256];
@@ -243,7 +243,7 @@ void unprotect_thread_critical_region(void);
static void
ett_win_destroy_cb(GtkWindow *win _U_, gpointer data)
{
- endpoints_table *talkers=(endpoints_table *)data;
+ conversations_table *talkers=(conversations_table *)data;
protect_thread_critical_region();
remove_tap_listener(talkers);
@@ -356,7 +356,7 @@ ett_select_filter_cb(GtkWidget *widget _U_, gpointer callback_data, guint callba
{
int action, type, direction;
int selection;
- endpoints_table *et = (endpoints_table *)callback_data;
+ conversations_table *et = (conversations_table *)callback_data;
char dirstr[128];
char str[256];
const char *current_filter;
@@ -560,7 +560,7 @@ ett_select_filter_cb(GtkWidget *widget _U_, gpointer callback_data, guint callba
}
static gint
-ett_show_popup_menu_cb(void *widg _U_, GdkEvent *event, endpoints_table *et)
+ett_show_popup_menu_cb(void *widg _U_, GdkEvent *event, conversations_table *et)
{
GdkEventButton *bevent = (GdkEventButton *)event;
gint row;
@@ -919,7 +919,7 @@ static GtkItemFactoryEntry ett_list_menu_items[] =
};
static void
-ett_create_popup_menu(endpoints_table *et)
+ett_create_popup_menu(conversations_table *et)
{
GtkItemFactory *item_factory;
@@ -934,7 +934,7 @@ ett_create_popup_menu(endpoints_table *et)
/* XXX should freeze/thaw table here and in the srt thingy? */
static void
-draw_ett_table_addresses(endpoints_table *et)
+draw_ett_table_addresses(conversations_table *et)
{
guint32 i;
int j;
@@ -1008,7 +1008,7 @@ draw_ett_table_addresses(endpoints_table *et)
static void
-draw_ett_table_data(endpoints_table *et)
+draw_ett_table_data(conversations_table *et)
{
guint32 i;
int j;
@@ -1060,7 +1060,7 @@ draw_ett_table_data(endpoints_table *et)
gboolean
-init_ett_table_page(endpoints_table *talkers, GtkWidget *vbox, gboolean hide_ports, char *table_name, char *tap_name, char *filter, void *packet_func)
+init_ett_table_page(conversations_table *talkers, GtkWidget *vbox, gboolean hide_ports, char *table_name, char *tap_name, char *filter, void *packet_func)
{
int i;
column_arrows *col_arrows;
@@ -1169,7 +1169,7 @@ init_ett_table_page(endpoints_table *talkers, GtkWidget *vbox, gboolean hide_por
void
init_ett_table(gboolean hide_ports, char *table_name, char *tap_name, char *filter, void *packet_func)
{
- endpoints_table *talkers;
+ conversations_table *talkers;
char title[256];
GtkWidget *vbox;
GtkWidget *bbox;
@@ -1177,7 +1177,7 @@ init_ett_table(gboolean hide_ports, char *table_name, char *tap_name, char *filt
gboolean ret;
- talkers=g_malloc(sizeof(endpoints_table));
+ talkers=g_malloc(sizeof(conversations_table));
talkers->name=table_name;
g_snprintf(title, 255, "%s Conversations: %s", table_name, cf_get_display_name(&cfile));
@@ -1232,14 +1232,14 @@ ett_win_destroy_notebook_cb(GtkWindow *win _U_, gpointer data)
-static endpoints_table *
+static conversations_table *
init_ett_notebook_page_cb(gboolean hide_ports, char *table_name, char *tap_name, char *filter, void *packet_func)
{
gboolean ret;
GtkWidget *page_vbox;
- endpoints_table *talkers;
+ conversations_table *talkers;
- talkers=g_malloc(sizeof(endpoints_table));
+ talkers=g_malloc(sizeof(conversations_table));
talkers->name=table_name;
talkers->resolve_names=TRUE;
@@ -1291,7 +1291,7 @@ ett_resolve_toggle_dest(GtkWidget *widget, gpointer data)
int page;
void ** pages = data;
gboolean resolve_names;
- endpoints_table *talkers;
+ conversations_table *talkers;
resolve_names = gtk_toggle_button_get_active(GTK_TOGGLE_BUTTON (widget));
@@ -1307,7 +1307,7 @@ ett_resolve_toggle_dest(GtkWidget *widget, gpointer data)
void
init_ett_notebook_cb(GtkWidget *w _U_, gpointer d _U_)
{
- endpoints_table *talkers;
+ conversations_table *talkers;
char title[256];
GtkWidget *vbox;
GtkWidget *hbox;
@@ -1389,13 +1389,13 @@ init_ett_notebook_cb(GtkWidget *w _U_, gpointer d _U_)
void
-add_ett_table_data(endpoints_table *et, address *src, address *dst, guint32 src_port, guint32 dst_port, int num_frames, int num_bytes, SAT_E sat, int port_type)
+add_ett_table_data(conversations_table *et, address *src, address *dst, guint32 src_port, guint32 dst_port, int num_frames, int num_bytes, SAT_E sat, int port_type)
{
address *addr1, *addr2;
guint32 port1, port2;
- endpoint_talker_t *talker=NULL;
- int talker_idx=0;
- gboolean new_talker;
+ conversation_t *conversation=NULL;
+ int conversation_idx=0;
+ gboolean new_conversation;
if(src_port>dst_port){
addr1=src;
@@ -1420,70 +1420,70 @@ add_ett_table_data(endpoints_table *et, address *src, address *dst, guint32 src_
}
- new_talker=FALSE;
+ new_conversation=FALSE;
/* XXX should be optimized to allocate n extra entries at a time
instead of just one */
/* if we dont have any entries at all yet */
if(et->endpoints==NULL){
- et->endpoints=g_malloc(sizeof(endpoint_talker_t));
+ et->endpoints=g_malloc(sizeof(conversation_t));
et->num_endpoints=1;
- talker=&et->endpoints[0];
- talker_idx=0;
- new_talker=TRUE;
+ conversation=&et->endpoints[0];
+ conversation_idx=0;
+ new_conversation=TRUE;
}
- /* try to find it among the existing known talkers */
- if(talker==NULL){
+ /* try to find it among the existing known conversations */
+ if(conversation==NULL){
guint32 i;
for(i=0;i<et->num_endpoints;i++){
if( (!CMP_ADDRESS(&et->endpoints[i].src_address, addr1))&&(!CMP_ADDRESS(&et->endpoints[i].dst_address, addr2))&&(et->endpoints[i].src_port==port1)&&(et->endpoints[i].dst_port==port2) ){
- talker=&et->endpoints[i];
- talker_idx=i;
+ conversation=&et->endpoints[i];
+ conversation_idx=i;
break;
}
if( (!CMP_ADDRESS(&et->endpoints[i].src_address, addr2))&&(!CMP_ADDRESS(&et->endpoints[i].dst_address, addr1))&&(et->endpoints[i].src_port==port2)&&(et->endpoints[i].dst_port==port1) ){
- talker=&et->endpoints[i];
- talker_idx=i;
+ conversation=&et->endpoints[i];
+ conversation_idx=i;
break;
}
}
}
- /* if we still dont know what talker this is it has to be a new one
+ /* if we still dont know what conversation this is it has to be a new one
and we have to allocate it and append it to the end of the list */
- if(talker==NULL){
- new_talker=TRUE;
+ if(conversation==NULL){
+ new_conversation=TRUE;
et->num_endpoints++;
- et->endpoints=g_realloc(et->endpoints, et->num_endpoints*sizeof(endpoint_talker_t));
- talker=&et->endpoints[et->num_endpoints-1];
- talker_idx=et->num_endpoints-1;
+ et->endpoints=g_realloc(et->endpoints, et->num_endpoints*sizeof(conversation_t));
+ conversation=&et->endpoints[et->num_endpoints-1];
+ conversation_idx=et->num_endpoints-1;
}
- /* if this is a new talker we need to initialize the struct */
- if(new_talker){
- COPY_ADDRESS(&talker->src_address, addr1);
- COPY_ADDRESS(&talker->dst_address, addr2);
- talker->sat=sat;
- talker->port_type=port_type;
- talker->src_port=port1;
- talker->dst_port=port2;
- talker->rx_frames=0;
- talker->tx_frames=0;
- talker->rx_bytes=0;
- talker->tx_bytes=0;
+ /* if this is a new conversation we need to initialize the struct */
+ if(new_conversation){
+ COPY_ADDRESS(&conversation->src_address, addr1);
+ COPY_ADDRESS(&conversation->dst_address, addr2);
+ conversation->sat=sat;
+ conversation->port_type=port_type;
+ conversation->src_port=port1;
+ conversation->dst_port=port2;
+ conversation->rx_frames=0;
+ conversation->tx_frames=0;
+ conversation->rx_bytes=0;
+ conversation->tx_bytes=0;
}
/* update the talker struct */
if( (!CMP_ADDRESS(src, addr1))&&(!CMP_ADDRESS(dst, addr2))&&(src_port==port1)&&(dst_port==port2) ){
- talker->tx_frames+=num_frames;
- talker->tx_bytes+=num_bytes;
+ conversation->tx_frames+=num_frames;
+ conversation->tx_bytes+=num_bytes;
} else {
- talker->rx_frames+=num_frames;
- talker->rx_bytes+=num_bytes;
+ conversation->rx_frames+=num_frames;
+ conversation->rx_bytes+=num_bytes;
}
- /* if this was a new talker we have to create a clist row for it */
- if(new_talker){
+ /* if this was a new conversation we have to create a clist row for it */
+ if(new_conversation){
char *entries[NUM_COLS];
char frames[16],bytes[16],txframes[16],txbytes[16],rxframes[16],rxbytes[16];
@@ -1496,23 +1496,23 @@ add_ett_table_data(endpoints_table *et, address *src, address *dst, guint32 src_
entries[2] = "";
entries[3] = "";
- g_snprintf(frames, 16, "%u", talker->tx_frames+talker->rx_frames);
+ g_snprintf(frames, 16, "%u", conversation->tx_frames+conversation->rx_frames);
entries[4]=frames;
- g_snprintf(bytes, 16, "%u", talker->tx_bytes+talker->rx_bytes);
+ g_snprintf(bytes, 16, "%u", conversation->tx_bytes+conversation->rx_bytes);
entries[5]=bytes;
- g_snprintf(txframes, 16, "%u", talker->tx_frames);
+ g_snprintf(txframes, 16, "%u", conversation->tx_frames);
entries[6]=txframes;
- g_snprintf(txbytes, 16, "%u", talker->tx_bytes);
+ g_snprintf(txbytes, 16, "%u", conversation->tx_bytes);
entries[7]=txbytes;
- g_snprintf(rxframes, 16, "%u", talker->rx_frames);
+ g_snprintf(rxframes, 16, "%u", conversation->rx_frames);
entries[8]=rxframes;
- g_snprintf(rxbytes, 16, "%u", talker->rx_bytes);
+ g_snprintf(rxbytes, 16, "%u", conversation->rx_bytes);
entries[9]=rxbytes;
- gtk_clist_insert(et->table, talker_idx, entries);
- gtk_clist_set_row_data(et->table, talker_idx, (gpointer) talker_idx);
+ gtk_clist_insert(et->table, conversation_idx, entries);
+ gtk_clist_set_row_data(et->table, conversation_idx, (gpointer) conversation_idx);
gtk_clist_thaw(et->table);
}
@@ -1,8 +1,8 @@
/* mem leak should free the column_arrows when the table is destroyed */
-/* endpoint_talkers_table.c
- * endpoint_talkers_table 2003 Ronnie Sahlberg
- * Helper routines common to all endpoint talkers tap.
+/* conversations_table.c
+ * conversations_table 2003 Ronnie Sahlberg
+ * Helper routines common to all endpoint conversations tap.
*
* $Id$
@@ -1420,70 +1420,70 @@ add_ett_table_data(endpoints_table *et, address *src, address *dst, guint32 src_
}
- /* update the talker struct */
+ /* update the conversation struct */
if( (!CMP_ADDRESS(src, addr1))&&(!CMP_ADDRESS(dst, addr2))&&(src_port==port1)&&(dst_port==port2) ){
diff --git a/gtk/endpoint_talkers_table.h b/gtk/conversations_table.h
index 9b8b3c6a43..549a94d8c0 100644
--- a/gtk/endpoint_talkers_table.h
+++ b/gtk/conversations_table.h
@@ -1,6 +1,6 @@
/* endpoint_talkers_table.h
* endpoint_talkers_table 2003 Ronnie Sahlberg
* Helper routines common to all endpoint talkers taps.
*
* $Id$
*
@@ -30,7 +30,7 @@
*/
/** Conversation information */
-typedef struct _endpoint_talker_t {
+typedef struct _conversation_t {
address src_address; /**< source address */
address dst_address; /**< destination address */
SAT_E sat; /**< address type */
@@ -42,10 +42,10 @@ typedef struct _endpoint_talker_t {
guint32 tx_frames; /**< number of transmitted packets */
guint32 rx_bytes; /**< number of received bytes */
guint32 tx_bytes; /**< number of transmitted bytes */
-} endpoint_talker_t;
+} conversation_t;
/** Conversation widget */
-typedef struct _endpoints_table {
+typedef struct _conversations_table {
char *name; /**< the name of the table */
GtkWidget *win; /**< GTK window */
GtkWidget *page_lb; /**< label */
@@ -53,10 +53,10 @@ typedef struct _endpoints_table {
GtkCList *table; /**< the GTK table */
GtkWidget *menu; /**< context menu */
gboolean has_ports; /**< table has ports */
- guint32 num_endpoints; /**< number of endpoints (0 or 1) */
- endpoint_talker_t *endpoints; /**< array of conversation values */
+ guint32 num_endpoints; /**< number of conversations */
+ conversation_t *endpoints; /**< array of conversation values */
gboolean resolve_names; /**< resolve address names? */
-} endpoints_table;
+} conversations_table;
/** Register the conversation table for the multiple conversation window.
*
@@ -87,7 +87,7 @@ extern void init_ett_notebook_cb(GtkWidget *w, gpointer d);
/** Add some data to the table.
*
- * @param et the table to add the data to
+ * @param ct the table to add the data to
* @param src source address
* @param dst destination address
* @param src_port source port
@@ -97,5 +97,5 @@ extern void init_ett_notebook_cb(GtkWidget *w, gpointer d);
* @param sat address type
* @param port_type the port type (e.g. PT_TCP)
*/
-extern void add_ett_table_data(endpoints_table *et, address *src, address *dst,
+extern void add_ett_table_data(conversations_table *ct, address *src, address *dst,
guint32 src_port, guint32 dst_port, int num_frames, int num_bytes, SAT_E sat, int port_type);
@@ -1,6 +1,6 @@
-/* endpoint_talkers_table.h
- * endpoint_talkers_table 2003 Ronnie Sahlberg
- * Helper routines common to all endpoint talkers taps.
+/* conversations_table.h
+ * conversations_table 2003 Ronnie Sahlberg
+ * Helper routines common to all conversations taps.
*
* $Id$